import os
import sys
import getopt
import json
import codecs
from dateutil import parser


BAIL = False

NAME = 'Sigil'

# Blog post template
POST = """---
title: {}
date: {}
categories:
  - Blog
tags:
  - Releases
  - {}
---

{}

{}

"""

# Map asset filename patterns to link text
asset_patterns = {
    'CHECKSUMS.sha256.txt'     : 'CHECKSUMS file',
    'Windows-Setup.exe'        : 'Windows x86 download',
    'Windows-x64-Setup.exe'    : 'Windows x64 download',
    'Windows-Legacy-Setup.exe' : 'Windows Legacy download',
    'Mac-x86_64.txz'           : 'MacOS (Intel) download',
    'Mac-arm64.txz'            : 'MacOS (Arm64) download',
    'x86_64.AppImage'          : 'Linux AppImage download'
}

link = "[{}]({}){{: .btn .btn--success}}<br/>"

def rchop(s, sub):
    return s[:-len(sub)] if s.endswith(sub) else s

# Get asset download urls from release  event payload 
def get_asset_links(assets):
    md_links =[]
    for asset in assets:
        for p, t in asset_patterns.items():
            if p in asset['name']:
                if not asset['name'].endswith('.zsync'):
                    md_links.append(link.format(t, asset['browser_download_url']))

    print(md_links)
    return rchop('\n'.join(md_links), '<br/>')


def main(argv):
    global BAIL
    global POST
    path = ''
    try:
        opts, args = getopt.getopt(argv,"hp:",["path="])
    except getopt.GetoptError:
        print ('make_post.py -p <path>')
        sys.exit(2)
    for opt, arg in opts:
        if opt == '-h':
            print ('make_post.py -p <path>')
            sys.exit()
        elif opt in ("-p", "--path"):
            path = arg

    # Open and serialize release event payload
    with codecs.open(path, 'r', 'utf-8') as f:
        j = json.load(f)
    r = j['release']
    date = parser.parse(r['published_at'])
    title = r['name'] + ' Released'

    # file name for blog post
    filename = os.path.join('.', date.strftime('%Y-%m-%d') + '-' + title.lower().replace(' ', '-') + '.md')
    print(filename)

    links = get_asset_links(r['assets'])

    # Plug relevant data into post template
    md = POST.format(title, r['published_at'], NAME, links, r['body'])
    print(md)

    # Write post to file
    with codecs.open(filename, 'w', 'utf-8') as f:
        f.write(md)
    sys.exit()

if __name__ == "__main__":
   main(sys.argv[1:])



#!/usr/bin/env python3
# vim:fileencoding=UTF-8:ts=4:sw=4:sta:et:sts=4:ai

import os, sys, glob

exclude_libs = [
    "libatk-1.0.so.0",
    "libatk-bridge-2.0.so.0",
    "libatspi.so.0",
    "libblkid.so.1",
    "libbsd.so.0",
    "libcairo-gobject.so.2",
    "libcairo.so.2",
    "libcapnp-0.5.3.so",
    "libcapnp-0.6.1.so",
    "libdatrie.so.1",
    "libdbus-1.so.3",
    "libepoxy.so.0",
    "libffi.so.6",
    "libgcrypt.so.20",
    "libgdk-3.so.0",
    #"libgdk_pixbuf-2.0.so.0",
    "libgdk-x11-2.0.so.0",
    "libgio-2.0.so.0",
    "libglib-2.0.so.0",
    "libgmodule-2.0.so.0",
    "libgobject-2.0.so.0",
    "libgraphite2.so.3",
    "libgtk-3.so.0",
    "libgtk-x11-2.0.so.0",
    "libkj-0.5.3.so",
    "libkj-0.6.1.so",
    "liblz4.so.1",
    "liblzma.so.5",
    "libmirclient.so.9",
    "libmircommon.so.7",
    "libmircore.so.1",
    "libmirprotobuf.so.3",
    "libmount.so.1",
    "libpango-1.0.so.0",
    "libpangocairo-1.0.so.0",
    "libpangoft2-1.0.so.0",
    "libpcre2-8.so.0",
    "libpcre.so.3",
    "libpixman-1.so.0",
    "libprotobuf-lite.so.9",
    "libreadline.so.8",
    "libselinux.so.1",
    "libsystemd.so.0",
    "libthai.so.0",
    "libwayland-client.so.0",
    "libwayland-cursor.so.0",
    "libwayland-egl.so.1",
    "libwayland-server.so.0",
    "libX11-xcb.so.1",
    "libXau.so.6",
    #"libxcb-cursor.so.0",
    #"libxcb-glx.so.0",
    #"libxcb-icccm.so.4",
    #"libxcb-image.so.0",
    #"libxcb-keysyms.so.1",
    #"libxcb-randr.so.0",
    #"libxcb-render.so.0",
    #"libxcb-render-util.so.0",
    #"libxcb-shape.so.0",
    #"libxcb-shm.so.0",
    #"libxcb-sync.so.1",
    #"libxcb-util.so.1",
    #"libxcb-xfixes.so.0",
    #"libxcb-xkb.so.1",
    "libXcomposite.so.1",
    "libXcursor.so.1",
    "libXdamage.so.1",
    "libXdmcp.so.6",
    "libXext.so.6",
    "libXfixes.so.3",
    "libXinerama.so.1",
    "libXi.so.6",
    #"libxkbcommon.so.0",
    #"libxkbcommon-x11.so.0",
    "libXrandr.so.2",
    "libXrender.so.1",
]

def remove_libs(pth):
    for f in exclude_libs:
        libpth = os.path.join(pth, f)
        if os.path.isfile(libpth):
            os.remove(libpth)
        else:
            # If it fails, inform the user.
            print(f"{f} not found")

    dupe_pyside = glob.glob('{}/libpyside6*'.format(pth))
    if len(dupe_pyside):
        print('pyside libs {}'.format(dupe_pyside))
        for f in dupe_pyside:
            if os.path.isfile(f):
                os.remove(f)

    dupe_shiboken = glob.glob('{}/libshiboken6*'.format(pth))
    if len(dupe_shiboken):
        print('shiboken libs {}'.format(dupe_shiboken))
        for f in dupe_shiboken:
            if os.path.isfile(f):
                os.remove(f)

def clean_pillow_libs(srcd, destd):
    print('src {}'.format(srcd))
    print('dest {}'.format(destd))
    pillow_libs = next(os.walk(srcd), (None, None, []))[2]  # [] if no file
    #pillow_libs = glob.glob('{}/*'.format(srcd))
    print('pillow.libs {}'.format(pillow_libs))
    for entry in pillow_libs:
        f = os.path.join(destd, entry)
        print('File to remove {}'.format(f))
        if os.path.isfile(f):
            os.remove(f)

if __name__ == '__main__':
    appimagelib_path = sys.argv[1]
    py_ver = sys.argv[2]
    pil_src = os.path.join(appimagelib_path, 'python{}'.format(py_ver), 'site-packages', 'pillow.libs')
    remove_libs(appimagelib_path)
    clean_pillow_libs(pil_src, appimagelib_path)
